{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#gunzip.cwl",
            "doc": "gunzip files",
            "baseCommand": [
                "gunzip"
            ],
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#gunzip.cwl/gunzip files/gz_file"
                }
            ],
            "stdout": "$(inputs.gz_file.nameroot)",
            "outputs": [
                {
                    "type": "File",
                    "id": "#gunzip.cwl/gunzip files/unzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.gz_file.nameroot)"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#mosdepth-awk-thresholds-bed-to-coverage-QC.cwl",
            "label": "awk",
            "doc": "awk parse thresholds.bed to make {sample}_Failed_Exon_coverage_QC.txt\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "awk",
                "FNR > 1 { LEN = $3-$2; PCT100 = $5/LEN*100; PCT250 = $6/LEN*100; split($4, a, \"_\"); gsub(/[[:alpha:]]/, \"\", a[2]); if (PCT100 < 50 && a[3] ~ /^NM/) { printf \"%s\\t%s\\t%s\\t%d\\t%.1f\\t%.1f\\n\", $4, a[1], a[3], a[2], PCT100, PCT250 } }"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#mosdepth-awk-thresholds-bed-to-coverage-QC.cwl/awk/thresholds_bed"
                }
            ],
            "stdout": "$(inputs.thresholds_bed.nameroot.split('.')[0]).coverage_QC",
            "outputs": [
                {
                    "type": "File",
                    "id": "#mosdepth-awk-thresholds-bed-to-coverage-QC.cwl/awk/coverage_QC",
                    "outputBinding": {
                        "glob": "$(inputs.thresholds_bed.nameroot.split('.')[0]).coverage_QC"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#mosdepth-thresholds-bed-to-target-region-coverage.cwl",
            "label": "target_region_coverage_metrics.py",
            "doc": "from mosdepth output 'thresholds.bed.gz' to make consensus reads coverage metrics\non target regions.\n",
            "requirements": [
                {
                    "dockerPull": "umccr/alpine_pandas:latest-cwl",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        {
                            "entryname": "target_region_coverage_metrics.py",
                            "entry": "#!/usr/bin/env python3\n\nimport pandas as pd\nfrom os import path\nimport argparse\n\ndef get_args():\n    \"\"\" Get arguments for the command \"\"\"\n    parser = argparse.ArgumentParser(description='From mosdepth threshold.bed to make consensus reads coverage on target region (TargetRegionCoverage.tsv)')\n\n    # add arguments\n    parser.add_argument('-i', '--input-bed', required=True,\n                        help='Mosdepth output file \"threshold.bed\", ungzipped')\n\n    parser.add_argument('-p', '--prefix', required=False,\n                        help='prefix of output TargetRegionCoverage.tsv')\n    return parser.parse_args()\n\ndef main():\n    \"\"\" Calculate consensus reads coverage metrics \"\"\"\n    args = get_args()\n    # thresholds_bed = args.input_bed\n    # sample_id = path.basename(thresholds_bed).split('.')[0]\n    if args.prefix:\n      output_tsv = args.prefix + '.TargetRegionCoverage.tsv'\n    else:\n      output_tsv = path.basename(args.input_bed).split('.')[0] + '.TargetRegionCoverage.tsv'\n\n    # open threshold.bed file and load to dataframe\n    with open(args.input_bed, 'rt') as i:\n        data = pd.read_csv(i, sep='\\t', header=0)\n    # calculate total legnth of targeted region\n    length_sum = pd.DataFrame.sum(data['end'] - data['start'])\n    # write results to file\n    with open(output_tsv, 'w') as o:\n        o.write('ConsensusReadDepth\\tBasePair\\tPercentage\\n')\n        o.write('TargetRegion\\t' + str(length_sum) + '\\t100%\\n')\n        for col in data.columns[4:]:\n            threshold_pass_nt = pd.DataFrame.sum(data[col])\n            percentage = format(threshold_pass_nt * 100 / length_sum, '.2f')\n            o.write(col + '\\t' + str(threshold_pass_nt) + '\\t' +  str(percentage) + '%' + '\\n')\nmain()\n"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "python3",
                "target_region_coverage_metrics.py"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-p",
                        "position": 1
                    },
                    "id": "#mosdepth-thresholds-bed-to-target-region-coverage.cwl/make_target_region_coverage_metrics/sample_id"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 0
                    },
                    "id": "#mosdepth-thresholds-bed-to-target-region-coverage.cwl/make_target_region_coverage_metrics/thresholds_bed"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.thresholds_bed.nameroot.split('.')[0]).TargetRegionCoverage.tsv"
                    },
                    "id": "#mosdepth-thresholds-bed-to-target-region-coverage.cwl/make_target_region_coverage_metrics/target_region_coverage_metrics"
                }
            ],
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Yinan Wang",
                    "https://schema.org/email": "mailto:ywang16@illumina.com"
                }
            ],
            "https://schema.org/codeRepository": "https://github.com/YinanWang16/tso500-ctdna-post-processing"
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "make Failed_Exon_coverage_QC.txt for pierianDx CGW",
            "doc": "Input is mosdepth output 'threshold.bed.gz'.\nOutputs are 'Failed_Exon_coverage_QC.txt' and 'target_region_coverage_metrics'.\n",
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/sample"
                },
                {
                    "type": "File",
                    "id": "#main/threshold_bed_gz"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/cat/coverage_QC_txt",
                    "id": "#main/exon_coverage_qc"
                },
                {
                    "type": "File",
                    "outputSource": "#main/coverage_metrics/target_region_coverage_metrics",
                    "id": "#main/target_region_coverage_metrics"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/coverage_QC/coverage_QC",
                            "id": "#main/cat/coverage_QC_data"
                        },
                        {
                            "source": "#main/echo/header_file",
                            "id": "#main/cat/header_txt"
                        }
                    ],
                    "out": [
                        "#main/cat/coverage_QC_txt"
                    ],
                    "run": {
                        "class": "CommandLineTool",
                        "baseCommand": [
                            "cat"
                        ],
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "id": "#main/cat/c6133f61-9b64-42c5-af4b-6e10267ec33a/coverage_QC_data"
                            },
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 0
                                },
                                "id": "#main/cat/c6133f61-9b64-42c5-af4b-6e10267ec33a/header_txt"
                            }
                        ],
                        "stdout": "$(inputs.coverage_QC_data.nameroot)_Failed_Exon_coverage_QC.txt",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#main/cat/c6133f61-9b64-42c5-af4b-6e10267ec33a/coverage_QC_txt",
                                "outputBinding": {
                                    "glob": "$(inputs.coverage_QC_data.nameroot)_Failed_Exon_coverage_QC.txt"
                                }
                            }
                        ],
                        "id": "#main/cat/c6133f61-9b64-42c5-af4b-6e10267ec33a"
                    },
                    "id": "#main/cat"
                },
                {
                    "run": "#mosdepth-awk-thresholds-bed-to-coverage-QC.cwl",
                    "in": [
                        {
                            "source": "#main/sample",
                            "id": "#main/coverage_QC/sample_id"
                        },
                        {
                            "source": "#main/gunzip/unzipped_file",
                            "id": "#main/coverage_QC/thresholds_bed"
                        }
                    ],
                    "out": [
                        "#main/coverage_QC/coverage_QC"
                    ],
                    "id": "#main/coverage_QC"
                },
                {
                    "run": "#mosdepth-thresholds-bed-to-target-region-coverage.cwl",
                    "in": [
                        {
                            "source": "#main/sample",
                            "id": "#main/coverage_metrics/sample_id"
                        },
                        {
                            "source": "#main/gunzip/unzipped_file",
                            "id": "#main/coverage_metrics/thresholds_bed"
                        }
                    ],
                    "out": [
                        "#main/coverage_metrics/target_region_coverage_metrics"
                    ],
                    "id": "#main/coverage_metrics"
                },
                {
                    "in": [],
                    "out": [
                        "#main/echo/header_file"
                    ],
                    "run": {
                        "class": "CommandLineTool",
                        "requirements": [
                            {
                                "listing": [
                                    {
                                        "entryname": "header.sh",
                                        "entry": "echo -e \"Level 2: 100x coverage for > 50% of positions was not achieved for the targeted exon regions listed below:\"\necho -e \"index\\tgene\\ttranscript_acc\\texon_id\\tGE100\\tGE250\"\n"
                                    }
                                ],
                                "class": "InitialWorkDirRequirement"
                            }
                        ],
                        "inputs": [],
                        "baseCommand": [
                            "bash",
                            "header.sh"
                        ],
                        "stdout": "header.txt",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#main/echo/336ec3eb-97ec-4d23-a329-9090fe0e08b4/header_file",
                                "outputBinding": {
                                    "glob": "header.txt"
                                }
                            }
                        ],
                        "id": "#main/echo/336ec3eb-97ec-4d23-a329-9090fe0e08b4"
                    },
                    "id": "#main/echo"
                },
                {
                    "run": "#gunzip.cwl",
                    "in": [
                        {
                            "source": "#main/threshold_bed_gz",
                            "id": "#main/gunzip/gz_file"
                        }
                    ],
                    "out": [
                        "#main/gunzip/unzipped_file"
                    ],
                    "id": "#main/gunzip"
                }
            ],
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/name": "Yinan Wang",
                    "https://schema.org/email": "mailto:ywang16@illumina.com"
                }
            ],
            "https://schema.org/codeRepository": "https://github.com/YinanWang16/tso500-ctdna-post-processing"
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "s": "https://schema.org/"
    }
}
